@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,33 +21,33 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: accesstable.php,v 1.21 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: accesstable.php,v 1.26 2004/07/02 19:45:23 alec Exp $
  */
 
 // lista moduw ktre zawsze s dostpne dla kadego
 
-$access[allow] = "^(welcome|copyrights|logout|chpasswd)$";
+$access[allow] = "^(welcome|copyrights|logout|chpasswd|quicksearch)$";
 
 $access[table][0][name]		= "peen dostp";
 $access[table][0][allow_reg]	= "^.*$";
 
 $access[table][1][name]		= "odczyt wszystkich danych";
-$access[table][1][allow_reg]	= "^((admin|balance|db|net|node|netdev|tariff|payment|user)(list|list(debt|disc)|info|view|debt|search|balance)|netdevmap|print)$";
+$access[table][1][allow_reg]	= "^((admin|balance|db|net|node|netdev|tariff|payment|user|usergroup)(list|info|view|search|balance)|netdevmap|print)$";
 
 $access[table][2][name]		= "wczanie i odczanie komputerw";
 $access[table][2][allow_reg]	= "^nodeset$";
 
 $access[table][3][name]		= "manipulacja finansami";
-$access[table][3][allow_reg]	= "^((tariff)(add|info|list|move|edit|delete)|(payment)(add|del|edit|info|list)|(balance|balance|userbalance)(new|add|ok)|(invoice|invoice(list|new)))$";
+$access[table][3][allow_reg]	= "^((tariff)(add|info|list|move|edit|delete)|(payment)(add|del|edit|info|list)|(balance|balance|userbalance)(new|add|ok)|(invoice|invoice(list|new|report)))$";
 
 $access[table][4][name]         = "przeadowywanie konfiguracji";
 $access[table][4][allow_reg]    = "^reload$";
 
 $access[table][5][name]		= "manipulacja kontami uytkownikw";
-$access[table][5][allow_reg]	= "^user(add|edit|del)$";
+$access[table][5][allow_reg]	= "^(user(add|edit|del)|nodewarn|usergroup(add|edit|delete|move))$";
 
 $access[table][6][name]		= "manipulacja danymi komputerw";
-$access[table][6][allow_reg]	= "^(node(add|scan|del|edit|set)|choose(mac|ip))$";
+$access[table][6][allow_reg]	= "^(node(add|scan|del|edit|set|warn)|choose(mac|ip))$";
 
 $access[table][7][name]         = "dostp do statystyk";
 $access[table][7][allow_reg]    = "^traffic$";
@@ -55,6 +55,9 @@ $access[table][7][allow_reg]    = "^traffic$";
 $access[table][8][name]         = "dostp do korespondencji seryjnej";
 $access[table][8][allow_reg]    = "^(mailing|mailingsend)$";
 
+$access[table][9][name]         = "dostp do Helpdesku (RT)";
+$access[table][9][allow_reg]    = "^((rtqueue|rtticket)(add|del|edit|info|view|list))$";
+
 $access[table][253][name]	= "brak dostpu do modyfikacji i zakadania nowych kont administratorw";
 $access[table][253][deny_reg]	= "^(admin(add|del|edit|passwd))$";
 
