@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: balanceadd.php,v 1.14 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: balanceadd.php,v 1.17 2004/04/12 18:25:52 chilek Exp $
  */
 
 $addbalance = $_POST['addbalance'];
@@ -29,8 +29,12 @@ $addbalance = $_POST['addbalance'];
 $_SESSION['addbc'] = $addbalance['comment'];
 $_SESSION['addbt'] = $addbalance['time'];
 $_SESSION['addbv'] = $addbalance['value'];
+if ($addbalance['taxvalue'] == 'zw.')
+	$addbalance['taxvalue'] = '';
+$_SESSION['addbtax'] = $addbalance['taxvalue'];
 
 $addbalance['value'] = str_replace(",",".",$addbalance['value']);
+$addbalance['taxvalue'] = str_replace(",",".",$addbalance['taxvalue']);
 
 if($addbalance['time']) {
 
@@ -44,30 +48,30 @@ if($addbalance['time']) {
 		unset($addbalance['time']);
 }
 
-if($addbalance[type]=="3"||$addbalance[type]=="4")
+if($addbalance['type']=="3"||$addbalance['type']=="4")
 	{
-		if(isset($addbalance[muserid]))
+		if(isset($addbalance['muserid']))
 		{
-			foreach($addbalance[muserid] as $value)
+			foreach($addbalance['muserid'] as $value)
 				if($LMS->UserExists($value))
 				{
-					$addbalance[userid]=$value;
+					$addbalance['userid']=$value;
 					$LMS->AddBalance($addbalance);
 				}
 		}
 		else
 		{
-			if($LMS->UserExists($addbalance[userid]))
+			if($LMS->UserExists($addbalance['userid']))
 				$LMS->AddBalance($addbalance);
 		}
 	}
 
-	if($addbalance[type]=="2"||$addbalance[type]=="1")
+	if($addbalance['type']=="2"||$addbalance['type']=="1")
 	{
-		$addbalance[userid] = "0";
+		$addbalance['userid'] = "0";
 		$LMS->AddBalance($addbalance);
 	}
 
-header("Location: ?".$_SESSION[backto]);
+header("Location: ?".$_SESSION['backto']);
 
 ?>
