@@ -1,9 +1,9 @@
 <?
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.4 Terok
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,29 +21,28 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: confgen.php,v 1.2 2003/12/04 04:39:14 lukasz Exp $
+ *  $Id: confgen.php,v 1.7 2004/03/11 17:24:21 lukasz Exp $
  */
 
 // zacznijmy od budowania listy hostw:
 
-if($_GET[tpl] == '')
+if($_GET['tpl'] == '')
 {
-	$layout[pagetitle] = 'Pliki konfiguracyjne';
+	$layout['pagetitle'] = 'Pliki konfiguracyjne';
 	$templateslist = $LMS->GetTemplatesList();
 	$SMARTY->assign('templateslist',$templateslist);
-	$SMARTY->assign('layout',$layout);
 	$SMARTY->display('confgen.html');
 }
 else
 {
 	echo '<PRE>';
 	$arrays = $LMS->GetTemplateArrays();
-//	print_r($arrays[users]);
 	foreach($arrays as $arrayname => $array)
 		$SMARTY->assign($arrayname, &$array);
 	$SMARTY->template_dir = $LMS->CONFIG['directories']['config_templates_dir'];
 	$SMARTY->left_delimiter = '<?';
 	$SMARTY->right_delimiter = '?>';
-	$SMARTY->display($_GET[tpl].'.tpl');
+	$SMARTY->display($_GET['tpl'].'.tpl');
 }
+
 ?>
