@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.4 Terok
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,22 +21,13 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: copyrights.php,v 1.15 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: copyrights.php,v 1.20 2004/03/11 17:24:21 lukasz Exp $
  */
 
-$layout[pagetitle]="Informacje o prawach autorskich";
-$SMARTY->assign("layout",$layout);
-$SMARTY->display("header.html");
-$SMARTY->display("copyrights.html");
-$SMARTY->display("footer.html");
-/*
- * $Log: copyrights.php,v $
- * Revision 1.15  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.14  2003/08/18 16:52:19  lukasz
- * - added CVS Log tags
- *
- */
+$layout['pagetitle'] = "Informacje o prawach autorskich";
+
+$SMARTY->display('header.html');
+$SMARTY->display('copyrights.html');
+$SMARTY->display('footer.html');
+
 ?>
\ No newline at end of file
