@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: dbdel.php,v 1.19 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: dbdel.php,v 1.20 2004/03/11 17:24:21 lukasz Exp $
  */
 
 if($_GET['is_sure'])
@@ -32,7 +32,6 @@ if($_GET['is_sure'])
 } else
 {
 	$layout['pagetitle'] = "Usunicie bazy danych";
-	$SMARTY->assign('layout',$layout);
 	$SMARTY->display('header.html');
 	echo "<H1>Usunicie bazy danych</H1>";
 	echo "<p>Czy jeste pewien e chcesz usun baz danych utworzon ".date("Y/m/d H:i.s",$_GET['db'])."?</p>";
