@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: dbview.php,v 1.18 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: dbview.php,v 1.19 2004/03/11 17:24:21 lukasz Exp $
  */
 
 $layout['pagetitle'] = "Podgld bazy danych";
@@ -40,7 +40,6 @@ if($_GET['rawmode']=="true")
 		header("Content-Type: text/plain; charset=ISO-8859-2");
 }
 
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('database',$database);
 if(!$database['rawmode'])
 	$SMARTY->display('header.html');
