@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoice.php,v 1.22 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: invoice.php,v 1.24 2004/04/01 18:14:24 lukasz Exp $
  */
 header('Content-Type: '.$LMS->CONFIG['invoices']['content_type']);
 if($LMS->CONFIG['invoices']['attachment_name'] != '')
@@ -30,7 +30,6 @@ if($LMS->CONFIG['invoices']['attachment_name'] != '')
 if($_GET['print'] == 'cached' && sizeof($_POST['marks']))
 {
 	$layout['pagetitle'] = 'Faktury VAT';
-	$SMARTY->assign('layout',$layout);
 	$SMARTY->display('clearheader.html');
 	foreach($_POST['marks'] as $markid => $junk)
 		if($junk)
@@ -51,6 +50,21 @@ if($_GET['print'] == 'cached' && sizeof($_POST['marks']))
 	}
 	$SMARTY->display('clearfooter.html');
 }
+elseif($_GET['fetchsingle'])
+{
+	$invoice = $LMS->GetInvoiceContent($_GET['id']);
+	$ntempl = $LMS->CONFIG['invoices']['number_template'];
+	$ntempl = str_replace('%N',$invoice['number'],$ntempl);
+	$ntempl = str_replace('%M',$invoice['month'],$ntempl);
+	$ntempl = str_replace('%Y',$invoice['year'],$ntempl);
+	$layout['pagetitle'] = 'Faktura VAT nr '.$ntempl;
+	$invoice['last'] = TRUE;
+	$SMARTY->assign('invoice',$invoice);
+	$SMARTY->display('clearheader.html');
+	$SMARTY->assign('type','ORYGINA');
+	$SMARTY->display($LMS->CONFIG['invoices']['template_file']);
+	$SMARTY->display('clearfooter.html');
+}
 elseif($invoice = $LMS->GetInvoiceContent($_GET['id']))
 {
 	$ntempl = $LMS->CONFIG['invoices']['number_template'];
@@ -58,7 +72,6 @@ elseif($invoice = $LMS->GetInvoiceContent($_GET['id']))
 	$ntempl = str_replace('%M',$invoice['month'],$ntempl);
 	$ntempl = str_replace('%Y',$invoice['year'],$ntempl);
 	$layout['pagetitle'] = 'Faktura VAT nr '.$ntempl;	
-	$SMARTY->assign('layout',$layout);
 	$SMARTY->assign('invoice',$invoice);
 	$SMARTY->display('clearheader.html');
 	$SMARTY->assign('type','ORYGINA');
