@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,10 +21,11 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoicelist.php,v 1.12 2004/03/11 17:24:21 lukasz Exp $
+ *  $Id: invoicelist.php,v 1.13 2004/04/13 09:01:52 chilek Exp $
  */
 
 $layout['pagetitle'] = 'Lista faktur';
+$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
 
 $marks = $_POST['marks'];
 unset($marked);
