@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,14 +21,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: logout.php,v 1.20 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: logout.php,v 1.21 2004/07/05 23:26:57 lukasz Exp $
  */
 
-if($_GET['is_sure']=="1") 
+if($_GET['is_sure'] === 1) 
 {
 	$SESSION->LogOut();
-	header("Location: ?m=welcome");
+	header('Location: ?m=welcome');
 } else
-	header("Location: ?m=".$_SESSION['lastmodule']);    
+	header('Location: ?m='.$_SESSION['lastmodule']);    
 
-?>
\ No newline at end of file
+?>
