@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netadd.php,v 1.29 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: netadd.php,v 1.30 2004/03/11 17:24:22 lukasz Exp $
  */
 
 $netadd = $_POST['netadd'];
@@ -122,7 +122,6 @@ $layout['pagetitle'] = "Nowa sie";
 
 $prefixlist = $LMS->GetPrefixList();
 $netlist = $LMS->GetNetworkList();
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('error',$error);
 $SMARTY->assign('netadd',$netadd);
 $SMARTY->assign('prefixlist',$prefixlist);
