@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdel.php,v 1.21 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: netdel.php,v 1.22 2004/03/11 17:24:22 lukasz Exp $
  */
 
 if(!$LMS->NetworkExists($_GET['id']))
@@ -45,7 +45,6 @@ if(!$error)
 		die;
 	}else{
 		$layout['pagetitle'] = "Usunicie sieci ".strtoupper($network['name']);
-		$SMARTY->assign('layout',$layout);
 		$SMARTY->display('header.html');
 		echo "<H1>Usunicie sieci ".strtoupper($network['name'])."</H1>";
 		echo "<p>Czy jeste pewien e chcesz usun t sie?</p>";
@@ -54,7 +53,6 @@ if(!$error)
 	}
 }else{
 	$layout['pagetitle'] = "Informacja o sieci";
-	$SMARTY->assign('layout',$layout);
 	$SMARTY->assign('network',$network);
 	$SMARTY->assign('networks',$networks);
 	$SMARTY->assign('error',$error);
