@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdevadd.php,v 1.6 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: netdevadd.php,v 1.8 2004/03/15 14:08:41 alec Exp $
  */
 
 $netdevdata = $_POST['netdev'];
@@ -30,21 +30,22 @@ if(isset($netdevdata)) {
 	// Jakby to dziaao to by byo mio... :P
 	//if($netdevdata['ports'] !="" && !eregi("^[0-9]{,4}$",$netdevdata['ports']))
         //        $error['ports'] = "Podana ilo portw jest bdna!";
-	if($netdevdata['name'] == "")
-		$error['name'] = "Pole nazwa nie moe by puste!";
+	if($netdevdata['ports'] =='')
+		$netdevdata['ports'] = 0;
+	if($netdevdata['name'] == '')
+		$error['name'] = 'Pole nazwa nie moe by puste!';
 
         if(!$error)
         {
 	    $netdevid=$LMS->NetDevAdd($netdevdata);
-	    header("Location: ?m=netdevinfo&id=".$netdevid);
+	    header('Location: ?m=netdevinfo&id='.$netdevid);
 	    die;
         }
 }
 		
 
-$layout['pagetitle'] = "Nowe urzdzenie";
+$layout['pagetitle'] = 'Nowe urzdzenie';
 
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('error',$error);
 $SMARTY->assign('netdev',$netdevdata);
 $SMARTY->display('netdevadd.html');
