@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdevmap.php,v 1.16 2004/04/23 21:33:31 alec Exp $
+ *  $Id: netdevmap.php,v 1.18 2004/05/28 07:12:36 alec Exp $
 
                                  _
  _   ___      ____ _  __ _  __ _| |
@@ -195,7 +195,6 @@ else
 			$cely = $idy - $miny;
 			if(eregi('^n',$device))
 			{
-				
 				$device = str_replace('n','',$device);
 				list($nodeid,$device) = explode('.',$device);
 				$nodemap[$nodeid]['x'] = $celx;
@@ -250,8 +249,10 @@ else
 		$px = (($celx * ($cellw)) + $celllmargin);
 		$py = (($cely * ($cellh)) + $celltmargin);
 		imagecopy($im,$im_n,$px,$py,0,0,15,16);
-//		imagestring($im, 1, $px + 20, $py - 8, $nodeid.' ('.$celx.','.$cely.')', $blue);
-		imagestring($im, 1, $px + 20, $py + 2, $DB->GetOne('SELECT name FROM nodes WHERE id=?',array($nodeid)), $black);
+		$nodedata = $DB->GetRow('SELECT name, INET_NTOA(ipaddr) AS ip FROM nodes WHERE id=?',array($nodeid));
+//		imagestring($im, 1, $px + 15, $py - 8, $nodeid.' ('.$celx.','.$cely.')', $blue);
+		imagestring($im, 1, $px + 15, $py - 8, $nodedata['ip'], $blue);
+		imagestring($im, 1, $px + 15, $py + 2, $nodedata['name'], $black);
 	}
 				
 		
@@ -264,10 +265,14 @@ else
 		$py = (($cely * ($cellh)) + $celltmargin);
 		imagecopy($im,$im_nd,$px,$py,0,0,16,16);
 //		imagestring($im, 1, $px + 20, $py - 8, $deviceid.' ('.$celx.','.$cely.')', $blue);
+		$deviceip = $DB->GetCol('SELECT INET_NTOA(ipaddr) FROM nodes WHERE ownerid=0 AND netdev=? ORDER BY ipaddr', array($deviceid));
+		if($deviceip[0]) imagestring($im, 1, $px + 20, $py - ($deviceip[1]?17:8), $deviceip[0], $blue);
+		if($deviceip[1]) imagestring($im, 1, $px + 20, $py - 8, $deviceip[1], $blue);
+		if($deviceip[2]) imagestring($im, 1, $px + 20, $py + 17, $deviceip[2], $blue);
+		if($deviceip[3]) imagestring($im, 1, $px + 20, $py + 26, $deviceip[3], $blue);
 		imagestring($im, 3, $px + 20, $py + 2, $DB->GetOne('SELECT name FROM netdevices WHERE id=?',array($deviceid)), $darkred);
 	}
 	
-	
 		
 	imagepng($im);
 }
