@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtticketview.php,v 1.1 2004/03/11 23:12:15 lukasz Exp $
+ *  $Id: rtticketview.php,v 1.2 2004/07/02 11:24:52 alec Exp $
  */
 
 if(! $LMS->TicketExists($_GET['id']))
@@ -31,8 +31,10 @@ if(! $LMS->TicketExists($_GET['id']))
 }
 
 $ticket = $LMS->GetTicketContents($_GET['id']);
-$layout['pagetitle'] = 'Bilet #'.$ticket['ticketid'].' - '.$ticket['subject'];
+$layout['pagetitle'] = 'Zgoszenie #'.$ticket['ticketid'].' - '.$ticket['subject'];
+
+$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+
 $SMARTY->assign('ticket', $ticket);
 $SMARTY->display('rtticketview.html');
-?><PRE><? print_r($ticket);
-//layout['pagetitle']
+?>
