@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tariffedit.php,v 1.24 2004/04/07 13:41:18 chilek Exp $
+ *  $Id: tariffedit.php,v 1.25 2004/06/19 14:56:45 alec Exp $
  */
 
 if(!$LMS->TariffExists($_GET['id']))
@@ -39,12 +39,13 @@ if(isset($tariff))
 
 	$tariff['value'] = str_replace(',','.',$tariff['value']);
 	
-	if($tariff['uprate'] == '')
-		$tariff['uprate'] = 0;
-	
-	if($tariff['downrate'] == '')
-		$tariff['downrate'] = 0;
-	
+	if($tariff['uprate'] == '') $tariff['uprate'] = 0;
+	if($tariff['upceil'] == '') $tariff['upceil'] = 0;
+	if($tariff['downrate'] == '') $tariff['downrate'] = 0;
+	if($tariff['downceil'] == '') $tariff['downceil'] = 0;
+	if($tariff['climit'] == '') $tariff['climit'] = 0;
+	if($tariff['plimit'] == '') $tariff['plimit'] = 0;
+
 	if($tariff['name'] == '')
 		$error['name'] = 'Prosz poda nazw taryfy!';
 	elseif($LMS->GetTariffIDByName($tariff['name']) && $tariff['name'] != $LMS->GetTariffName($_GET['id']))
@@ -61,19 +62,29 @@ if(isset($tariff))
 
 	if(!(ereg("^[0-9]+$", $tariff['uprate'])))
 		$error['uprate'] = 'To pole musi zawiera liczb cakowit';
-	
 	if(!ereg('^[0-9]+$', $tariff['downrate']))
 		$error['downrate'] = 'To pole musi zawiera liczb cakowit';
+	if(!(ereg("^[0-9]+$", $tariff['upceil'])))
+		$error['upceil'] = 'To pole musi zawiera liczb cakowit';
+	if(!ereg('^[0-9]+$', $tariff['downceil']))
+		$error['downceil'] = 'To pole musi zawiera liczb cakowit';
+	if(!(ereg("^[0-9]+$", $tariff['climit'])))
+		$error['climit'] = 'To pole musi zawiera liczb cakowit';
+	if(!ereg('^[0-9]+$', $tariff['plimit']))
+		$error['plimit'] = 'To pole musi zawiera liczb cakowit';
 	
 	if(($tariff['uprate'] < 8 || $tariff['uprate'] > 4096) && $tariff['uprate'] != 0)
 		$error['uprate'] = 'To pole musi zawiera liczb z przedziau 8 - 4096';
-	
 	if(($tariff['downrate'] < 8 || $tariff['downrate'] > 4096) && $tariff['downrate'] != 0)
 		$error['downrate'] = 'To pole musi zawiera liczb z przedziau 8 - 4096';
+	if(($tariff['upceil'] < 8 || $tariff['upceil'] < $tariff['uprate']) && $tariff['upceil'] != 0)
+		$error['upceil'] = 'To pole musi zawiera liczb wiksz od 8 i wiksz od upload rate';
+	if(($tariff['downceil'] < 8 || $tariff['downceil'] < $tariff['downrate']) && $tariff['downceil'] != 0)
+		$error['downceil'] = 'To pole musi zawiera liczb wiksz od 8 i wiksz od download rate';
+
 
 	$tariff['id'] = $_GET['id'];
-//	$tariff['count'] = $LMS->GetUsersWithTariff($_GET['id']);	
-//	$tariff['totalval'] = $tariff['count'] * str_replace('.',',',$tariff['value']);
+
 	if(!$error)
 	{
 		$LMS->TariffUpdate($tariff);
