@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tarifflist.php,v 1.22 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: tarifflist.php,v 1.24 2004/03/18 07:59:13 alec Exp $
  */
 
 $layout['pagetitle'] = "Lista taryf";
@@ -32,12 +32,12 @@ $listdata['total'] = $tarifflist['total'];
 $listdata['totalincome'] = $tarifflist['totalincome'];
 $listdata['totalusers'] = $tarifflist['totalusers'];
 $listdata['totalcount'] = $tarifflist['totalcount'];
+$listdata['totalassignmentcount'] = $tarifflist['totalassignmentcount'];
 
-unset($tarifflist['total'],$tarifflist['totalincome'],$tarifflist['totalusers'],$tarifflist['totalcount']);
+unset($tarifflist['total'],$tarifflist['totalincome'],$tarifflist['totalusers'],$tarifflist['totalcount'],$tarifflist['totalassignmentcount']);
 
 $SMARTY->assign('tarifflist',$tarifflist);
 $SMARTY->assign('listdata',$listdata);
-$SMARTY->assign('layout',$layout);
 $SMARTY->display('tarifflist.html');
 
 ?>
