@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: upgrade01.php,v 1.6 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: upgrade01.php,v 1.8 2004/03/03 07:55:00 alec Exp $
  */
 
 $SMARTY->display('header.html');
@@ -32,9 +32,9 @@ $users = $DB->GetAll('SELECT * FROM users');
 $tariffs = $DB->GetAllByKey('SELECT * FROM tariffs','id');
 foreach($users as $idx => $row)
 {
-	echo $row[lastname]." ".$row[name].": ";
-	echo "taryfa: '".$tariffs[$row[tariff]][name]."'... ";
-	$LMS->AddAssignment(array('tariffid' => $row[tariff], 'at' => $row[payday], 'userid' => $row[id], 'period' => 0, 'invoice' => 0));
+	echo $row['lastname']." ".$row['name'].": ";
+	echo "taryfa: '".$tariffs[$row['tariff']]['name']."'... ";
+	$LMS->AddAssignment(array('tariffid' => $row['tariff'], 'at' => $row['payday'], 'userid' => $row['id'], 'period' => 1, 'invoice' => 0));
 	echo "ok.\n";
 }
 
