@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,9 +21,11 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: userbalance.php,v 1.24 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: userbalance.php,v 1.26 2004/06/03 15:32:39 chilek Exp $
  */
 
+$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+
 if(!$LMS->UserExists($_GET['id']))
 	header("Location: ?m=userlist");
 
@@ -33,7 +35,6 @@ $id = $_GET['id'];
 $layout['pagetitle'] = 'Rachunek uytkownika: <A HREF="?m=userinfo&id='.$_GET['id'].'">'.$username.'</A>';
 
 $SMARTY->assign('balancelist',$LMS->GetUserBalanceList($_GET['id']));
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('username',$username);
 $SMARTY->assign('id',$id);
 $SMARTY->display('userbalance.html');
